{
    "$graph": [
        {
            "class": "Workflow",
            "label": "wgs alignment with qc",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "record",
                            "name": "#labelled_file.yml/labelled_file",
                            "label": "a file with a label",
                            "fields": [
                                {
                                    "type": "File",
                                    "name": "#labelled_file.yml/labelled_file/file"
                                },
                                {
                                    "type": "string",
                                    "name": "#labelled_file.yml/labelled_file/label"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#sequence_data.yml/sequence_data",
                            "label": "sequence data with readgroup information",
                            "fields": [
                                {
                                    "type": "string",
                                    "name": "#sequence_data.yml/sequence_data/readgroup"
                                },
                                {
                                    "type": [
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/bam",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/bam/bam"
                                                }
                                            ]
                                        },
                                        {
                                            "type": "record",
                                            "name": "#sequence_data.yml/sequence_data/sequence/fastqs",
                                            "fields": [
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq1"
                                                },
                                                {
                                                    "type": "File",
                                                    "name": "#sequence_data.yml/sequence_data/sequence/fastqs/fastq2"
                                                }
                                            ]
                                        }
                                    ],
                                    "name": "#sequence_data.yml/sequence_data/sequence"
                                }
                            ]
                        },
                        {
                            "type": "record",
                            "name": "#trimming_options.yml/trimming_options",
                            "label": "trimming adapter file and parameters",
                            "fields": [
                                {
                                    "type": "File",
                                    "doc": "Fasta file with adapters for removal that may contain N.",
                                    "name": "#trimming_options.yml/trimming_options/adapters"
                                },
                                {
                                    "type": "int",
                                    "doc": "Minimum overlap for removal without pair overlap.",
                                    "name": "#trimming_options.yml/trimming_options/min_overlap"
                                }
                            ]
                        }
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#alignment_wgs.cwl/bqsr_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "One or more databases of known polymorphic sites used to exclude regions around known polymorphisms from analysis.",
                    "id": "#alignment_wgs.cwl/bqsr_known_sites"
                },
                {
                    "type": "File",
                    "id": "#alignment_wgs.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#alignment_wgs.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#alignment_wgs.cwl/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#alignment_wgs.cwl/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#alignment_wgs.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#alignment_wgs.cwl/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#alignment_wgs.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#alignment_wgs.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#alignment_wgs.cwl/sample_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#sequence_data.yml/sequence_data"
                    },
                    "id": "#alignment_wgs.cwl/sequence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#alignment_wgs.cwl/summary_intervals"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "id": "#alignment_wgs.cwl/trimming"
                }
            ],
            "steps": [
                {
                    "run": "#sequence_to_bqsr.cwl",
                    "in": [
                        {
                            "source": "#alignment_wgs.cwl/bqsr_intervals",
                            "id": "#alignment_wgs.cwl/alignment/bqsr_intervals"
                        },
                        {
                            "source": "#alignment_wgs.cwl/bqsr_known_sites",
                            "id": "#alignment_wgs.cwl/alignment/bqsr_known_sites"
                        },
                        {
                            "source": "#alignment_wgs.cwl/sample_name",
                            "id": "#alignment_wgs.cwl/alignment/final_name"
                        },
                        {
                            "source": "#alignment_wgs.cwl/reference",
                            "id": "#alignment_wgs.cwl/alignment/reference"
                        },
                        {
                            "source": "#alignment_wgs.cwl/trimming",
                            "id": "#alignment_wgs.cwl/alignment/trimming"
                        },
                        {
                            "source": "#alignment_wgs.cwl/sequence",
                            "id": "#alignment_wgs.cwl/alignment/unaligned"
                        }
                    ],
                    "out": [
                        "#alignment_wgs.cwl/alignment/final_bam",
                        "#alignment_wgs.cwl/alignment/mark_duplicates_metrics_file"
                    ],
                    "id": "#alignment_wgs.cwl/alignment"
                },
                {
                    "run": "#qc_wgs.cwl",
                    "in": [
                        {
                            "source": "#alignment_wgs.cwl/alignment/final_bam",
                            "id": "#alignment_wgs.cwl/qc/bam"
                        },
                        {
                            "source": "#alignment_wgs.cwl/intervals",
                            "id": "#alignment_wgs.cwl/qc/intervals"
                        },
                        {
                            "source": "#alignment_wgs.cwl/minimum_base_quality",
                            "id": "#alignment_wgs.cwl/qc/minimum_base_quality"
                        },
                        {
                            "source": "#alignment_wgs.cwl/minimum_mapping_quality",
                            "id": "#alignment_wgs.cwl/qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#alignment_wgs.cwl/omni_vcf",
                            "id": "#alignment_wgs.cwl/qc/omni_vcf"
                        },
                        {
                            "source": "#alignment_wgs.cwl/per_base_intervals",
                            "id": "#alignment_wgs.cwl/qc/per_base_intervals"
                        },
                        {
                            "source": "#alignment_wgs.cwl/per_target_intervals",
                            "id": "#alignment_wgs.cwl/qc/per_target_intervals"
                        },
                        {
                            "source": "#alignment_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#alignment_wgs.cwl/qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#alignment_wgs.cwl/reference",
                            "id": "#alignment_wgs.cwl/qc/reference"
                        },
                        {
                            "source": "#alignment_wgs.cwl/sample_name",
                            "id": "#alignment_wgs.cwl/qc/sample_name"
                        },
                        {
                            "source": "#alignment_wgs.cwl/summary_intervals",
                            "id": "#alignment_wgs.cwl/qc/summary_intervals"
                        }
                    ],
                    "out": [
                        "#alignment_wgs.cwl/qc/insert_size_metrics",
                        "#alignment_wgs.cwl/qc/insert_size_histogram",
                        "#alignment_wgs.cwl/qc/alignment_summary_metrics",
                        "#alignment_wgs.cwl/qc/gc_bias_metrics",
                        "#alignment_wgs.cwl/qc/gc_bias_metrics_chart",
                        "#alignment_wgs.cwl/qc/gc_bias_metrics_summary",
                        "#alignment_wgs.cwl/qc/wgs_metrics",
                        "#alignment_wgs.cwl/qc/flagstats",
                        "#alignment_wgs.cwl/qc/verify_bam_id_metrics",
                        "#alignment_wgs.cwl/qc/verify_bam_id_depth",
                        "#alignment_wgs.cwl/qc/per_base_coverage_metrics",
                        "#alignment_wgs.cwl/qc/per_base_hs_metrics",
                        "#alignment_wgs.cwl/qc/per_target_coverage_metrics",
                        "#alignment_wgs.cwl/qc/per_target_hs_metrics",
                        "#alignment_wgs.cwl/qc/summary_hs_metrics"
                    ],
                    "id": "#alignment_wgs.cwl/qc"
                }
            ],
            "id": "#alignment_wgs.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/alignment_summary_metrics",
                    "id": "#alignment_wgs.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/alignment/final_bam",
                    "id": "#alignment_wgs.cwl/bam"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/flagstats",
                    "id": "#alignment_wgs.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/gc_bias_metrics",
                    "id": "#alignment_wgs.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/gc_bias_metrics_chart",
                    "id": "#alignment_wgs.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/gc_bias_metrics_summary",
                    "id": "#alignment_wgs.cwl/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/insert_size_histogram",
                    "id": "#alignment_wgs.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/insert_size_metrics",
                    "id": "#alignment_wgs.cwl/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/alignment/mark_duplicates_metrics_file",
                    "id": "#alignment_wgs.cwl/mark_duplicates_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#alignment_wgs.cwl/qc/per_base_coverage_metrics",
                    "id": "#alignment_wgs.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#alignment_wgs.cwl/qc/per_base_hs_metrics",
                    "id": "#alignment_wgs.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#alignment_wgs.cwl/qc/per_target_coverage_metrics",
                    "id": "#alignment_wgs.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#alignment_wgs.cwl/qc/per_target_hs_metrics",
                    "id": "#alignment_wgs.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#alignment_wgs.cwl/qc/summary_hs_metrics",
                    "id": "#alignment_wgs.cwl/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/verify_bam_id_depth",
                    "id": "#alignment_wgs.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/verify_bam_id_metrics",
                    "id": "#alignment_wgs.cwl/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#alignment_wgs.cwl/qc/wgs_metrics",
                    "id": "#alignment_wgs.cwl/wgs_metrics"
                }
            ]
        },
        {
            "class": "Workflow",
            "label": "wgs alignment and germline variant detection",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        },
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        },
                        {
                            "$import": "#trimming_options.yml/trimming_options"
                        }
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "id": "#main/annotate_coding_only"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#main/bqsr_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "One or more databases of known polymorphic sites used to exclude regions around known polymorphisms from analysis.",
                    "id": "#main/bqsr_known_sites"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#main/emit_reference_confidence/NONE",
                            "#main/emit_reference_confidence/BP_RESOLUTION",
                            "#main/emit_reference_confidence/GVCF"
                        ]
                    },
                    "id": "#main/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#main/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/per_target_intervals"
                },
                {
                    "type": "string",
                    "id": "#main/picard_metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/ploidy"
                },
                {
                    "type": "File",
                    "id": "#main/qc_intervals"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#sequence_data.yml/sequence_data"
                    },
                    "id": "#main/sequence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#main/summary_intervals"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "id": "#main/synonyms_file"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "id": "#main/trimming"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/alignment_summary_metrics",
                    "id": "#main/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/index_cram/indexed_cram",
                    "id": "#main/cram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/flagstats",
                    "id": "#main/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics",
                    "id": "#main/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics_chart",
                    "id": "#main/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/gc_bias_metrics_summary",
                    "id": "#main/gc_bias_metrics_summary"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/generate_gvcfs/gvcf",
                    "id": "#main/gvcf"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/insert_size_histogram",
                    "id": "#main/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/insert_size_metrics",
                    "id": "#main/insert_size_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/mark_duplicates_metrics",
                    "id": "#main/mark_duplicates_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment_and_qc/per_base_coverage_metrics",
                    "id": "#main/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment_and_qc/per_base_hs_metrics",
                    "id": "#main/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment_and_qc/per_target_coverage_metrics",
                    "id": "#main/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment_and_qc/per_target_hs_metrics",
                    "id": "#main/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/alignment_and_qc/summary_hs_metrics",
                    "id": "#main/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/verify_bam_id_depth",
                    "id": "#main/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/verify_bam_id_metrics",
                    "id": "#main/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#main/alignment_and_qc/wgs_metrics",
                    "id": "#main/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#alignment_wgs.cwl",
                    "in": [
                        {
                            "source": "#main/bqsr_intervals",
                            "id": "#main/alignment_and_qc/bqsr_intervals"
                        },
                        {
                            "source": "#main/bqsr_known_sites",
                            "id": "#main/alignment_and_qc/bqsr_known_sites"
                        },
                        {
                            "source": "#main/qc_intervals",
                            "id": "#main/alignment_and_qc/intervals"
                        },
                        {
                            "source": "#main/minimum_base_quality",
                            "id": "#main/alignment_and_qc/minimum_base_quality"
                        },
                        {
                            "source": "#main/minimum_mapping_quality",
                            "id": "#main/alignment_and_qc/minimum_mapping_quality"
                        },
                        {
                            "source": "#main/omni_vcf",
                            "id": "#main/alignment_and_qc/omni_vcf"
                        },
                        {
                            "source": "#main/per_base_intervals",
                            "id": "#main/alignment_and_qc/per_base_intervals"
                        },
                        {
                            "source": "#main/per_target_intervals",
                            "id": "#main/alignment_and_qc/per_target_intervals"
                        },
                        {
                            "source": "#main/picard_metric_accumulation_level",
                            "id": "#main/alignment_and_qc/picard_metric_accumulation_level"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/alignment_and_qc/reference"
                        },
                        {
                            "source": "#main/sequence",
                            "id": "#main/alignment_and_qc/sequence"
                        },
                        {
                            "source": "#main/summary_intervals",
                            "id": "#main/alignment_and_qc/summary_intervals"
                        },
                        {
                            "source": "#main/trimming",
                            "id": "#main/alignment_and_qc/trimming"
                        }
                    ],
                    "out": [
                        "#main/alignment_and_qc/bam",
                        "#main/alignment_and_qc/mark_duplicates_metrics",
                        "#main/alignment_and_qc/insert_size_metrics",
                        "#main/alignment_and_qc/insert_size_histogram",
                        "#main/alignment_and_qc/alignment_summary_metrics",
                        "#main/alignment_and_qc/gc_bias_metrics",
                        "#main/alignment_and_qc/gc_bias_metrics_chart",
                        "#main/alignment_and_qc/gc_bias_metrics_summary",
                        "#main/alignment_and_qc/wgs_metrics",
                        "#main/alignment_and_qc/flagstats",
                        "#main/alignment_and_qc/verify_bam_id_metrics",
                        "#main/alignment_and_qc/verify_bam_id_depth",
                        "#main/alignment_and_qc/per_base_coverage_metrics",
                        "#main/alignment_and_qc/per_base_hs_metrics",
                        "#main/alignment_and_qc/per_target_coverage_metrics",
                        "#main/alignment_and_qc/per_target_hs_metrics",
                        "#main/alignment_and_qc/summary_hs_metrics"
                    ],
                    "id": "#main/alignment_and_qc"
                },
                {
                    "run": "#bam_to_cram.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_and_qc/bam",
                            "id": "#main/bam_to_cram/bam"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bam_to_cram/reference"
                        }
                    ],
                    "out": [
                        "#main/bam_to_cram/cram"
                    ],
                    "id": "#main/bam_to_cram"
                },
                {
                    "in": [
                        {
                            "source": "#main/alignment_and_qc/verify_bam_id_metrics",
                            "id": "#main/extract_freemix/verify_bam_id_metrics"
                        }
                    ],
                    "out": [
                        "#main/extract_freemix/freemix_score"
                    ],
                    "run": {
                        "class": "ExpressionTool",
                        "requirements": [
                            {
                                "class": "InlineJavascriptRequirement"
                            }
                        ],
                        "inputs": [
                            {
                                "type": "File",
                                "inputBinding": {
                                    "loadContents": true
                                },
                                "id": "#main/extract_freemix/3512b4ac-2b59-42bb-857a-941815627fed/verify_bam_id_metrics"
                            }
                        ],
                        "outputs": [
                            {
                                "type": [
                                    "null",
                                    "string"
                                ],
                                "id": "#main/extract_freemix/3512b4ac-2b59-42bb-857a-941815627fed/freemix_score"
                            }
                        ],
                        "expression": "${\n    var metrics = inputs.verify_bam_id_metrics.contents.split(\"\\n\");\n    if ( metrics[0].split(\"\\t\")[6] == 'FREEMIX' ) {\n        return {'freemix_score': metrics[1].split(\"\\t\")[6]};\n    } else {\n        return {'freemix_score:': null };\n    }\n}\n",
                        "id": "#main/extract_freemix/3512b4ac-2b59-42bb-857a-941815627fed"
                    },
                    "id": "#main/extract_freemix"
                },
                {
                    "run": "#gatk_haplotypecaller_iterator.cwl",
                    "in": [
                        {
                            "source": "#main/alignment_and_qc/bam",
                            "id": "#main/generate_gvcfs/bam"
                        },
                        {
                            "source": "#main/extract_freemix/freemix_score",
                            "id": "#main/generate_gvcfs/contamination_fraction"
                        },
                        {
                            "source": "#main/emit_reference_confidence",
                            "id": "#main/generate_gvcfs/emit_reference_confidence"
                        },
                        {
                            "source": "#main/gvcf_gq_bands",
                            "id": "#main/generate_gvcfs/gvcf_gq_bands"
                        },
                        {
                            "source": "#main/intervals",
                            "id": "#main/generate_gvcfs/intervals"
                        },
                        {
                            "source": "#main/ploidy",
                            "id": "#main/generate_gvcfs/ploidy"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/generate_gvcfs/reference"
                        }
                    ],
                    "out": [
                        "#main/generate_gvcfs/gvcf"
                    ],
                    "id": "#main/generate_gvcfs"
                },
                {
                    "run": "#index_cram.cwl",
                    "in": [
                        {
                            "source": "#main/bam_to_cram/cram",
                            "id": "#main/index_cram/cram"
                        }
                    ],
                    "out": [
                        "#main/index_cram/indexed_cram"
                    ],
                    "id": "#main/index_cram"
                }
            ],
            "id": "#main"
        },
        {
            "class": "Workflow",
            "label": "scatter GATK HaplotypeCaller over intervals",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence/NONE",
                            "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence/BP_RESOLUTION",
                            "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence/GVCF"
                        ]
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": {
                            "type": "array",
                            "items": "string"
                        }
                    },
                    "id": "#gatk_haplotypecaller_iterator.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/max_alternate_alleles"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "an optional string to prepend to the output filename",
                    "id": "#gatk_haplotypecaller_iterator.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/ploidy"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/read_filter"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/gvcf"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                    ],
                    "run": "#gatk_haplotype_caller.cwl",
                    "in": [
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/bam",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/bam"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/contamination_fraction",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/contamination_fraction"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/dbsnp_vcf",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/dbsnp_vcf"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/emit_reference_confidence",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/emit_reference_confidence"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/gvcf_gq_bands",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf_gq_bands"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/intervals",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/intervals"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/max_alternate_alleles",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/max_alternate_alleles"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/output_prefix",
                            "valueFrom": "${ var prefix = self !== null ? self : \"\"; if (inputs.intervals.length == 1 && inputs.intervals[0].match(/^[0-9A-Za-z]+$/)) { return prefix + inputs.intervals[0] + \".g.vcf.gz\"; } else { return prefix + \"output.g.vcf.gz\"; } }",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/output_file_name"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/ploidy",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/ploidy"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/read_filter",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/read_filter"
                        },
                        {
                            "source": "#gatk_haplotypecaller_iterator.cwl/reference",
                            "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/reference"
                        }
                    ],
                    "out": [
                        "#gatk_haplotypecaller_iterator.cwl/haplotype_caller/gvcf"
                    ],
                    "id": "#gatk_haplotypecaller_iterator.cwl/haplotype_caller"
                }
            ],
            "id": "#gatk_haplotypecaller_iterator.cwl"
        },
        {
            "class": "Workflow",
            "label": "HS Metrics workflow",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#hs_metrics.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/per_target_intervals"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#hs_metrics.cwl/reference"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#hs_metrics.cwl/summary_intervals"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics",
                    "id": "#hs_metrics.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics",
                    "id": "#hs_metrics.cwl/summary_hs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "base-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/output_prefix"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_base_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_base_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_base_hs_metrics/per_base_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_base_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "target-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": true,
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/per_target_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_per_target_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/hs_metrics",
                        "#hs_metrics.cwl/collect_per_target_hs_metrics/per_target_coverage_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_per_target_hs_metrics"
                },
                {
                    "run": "#collect_hs_metrics.cwl",
                    "scatter": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals",
                        "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/bait_intervals"
                        },
                        {
                            "source": "#hs_metrics.cwl/bam",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/bam"
                        },
                        {
                            "valueFrom": "ALL_READS",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_base_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/minimum_mapping_quality",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "summary-$(self.label)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/output_prefix"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_base_coverage"
                        },
                        {
                            "default": false,
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/per_target_coverage"
                        },
                        {
                            "source": "#hs_metrics.cwl/reference",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/reference"
                        },
                        {
                            "source": "#hs_metrics.cwl/summary_intervals",
                            "valueFrom": "$(self.file)",
                            "id": "#hs_metrics.cwl/collect_summary_hs_metrics/target_intervals"
                        }
                    ],
                    "out": [
                        "#hs_metrics.cwl/collect_summary_hs_metrics/hs_metrics"
                    ],
                    "id": "#hs_metrics.cwl/collect_summary_hs_metrics"
                }
            ],
            "id": "#hs_metrics.cwl"
        },
        {
            "class": "Workflow",
            "label": "WGS QC workflow",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#labelled_file.yml/labelled_file"
                        }
                    ]
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#qc_wgs.cwl/bam"
                },
                {
                    "type": "File",
                    "id": "#qc_wgs.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#qc_wgs.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#qc_wgs.cwl/minimum_mapping_quality"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#qc_wgs.cwl/omni_vcf"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_wgs.cwl/per_base_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_wgs.cwl/per_target_intervals"
                },
                {
                    "type": "string",
                    "default": "ALL_READS",
                    "id": "#qc_wgs.cwl/picard_metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#qc_wgs.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#qc_wgs.cwl/sample_name"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#labelled_file.yml/labelled_file"
                    },
                    "id": "#qc_wgs.cwl/summary_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/collect_alignment_summary_metrics/alignment_summary_metrics",
                    "id": "#qc_wgs.cwl/alignment_summary_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/samtools_flagstat/flagstats",
                    "id": "#qc_wgs.cwl/flagstats"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics",
                    "id": "#qc_wgs.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_chart",
                    "id": "#qc_wgs.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_summary",
                    "id": "#qc_wgs.cwl/gc_bias_metrics_summary"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/collect_insert_size_metrics/insert_size_histogram",
                    "id": "#qc_wgs.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/collect_insert_size_metrics/insert_size_metrics",
                    "id": "#qc_wgs.cwl/insert_size_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_wgs.cwl/collect_hs_metrics/per_base_coverage_metrics",
                    "id": "#qc_wgs.cwl/per_base_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_wgs.cwl/collect_hs_metrics/per_base_hs_metrics",
                    "id": "#qc_wgs.cwl/per_base_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_wgs.cwl/collect_hs_metrics/per_target_coverage_metrics",
                    "id": "#qc_wgs.cwl/per_target_coverage_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_wgs.cwl/collect_hs_metrics/per_target_hs_metrics",
                    "id": "#qc_wgs.cwl/per_target_hs_metrics"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#qc_wgs.cwl/collect_hs_metrics/summary_hs_metrics",
                    "id": "#qc_wgs.cwl/summary_hs_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/verify_bam_id/verify_bam_id_depth",
                    "id": "#qc_wgs.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/verify_bam_id/verify_bam_id_metrics",
                    "id": "#qc_wgs.cwl/verify_bam_id_metrics"
                },
                {
                    "type": "File",
                    "outputSource": "#qc_wgs.cwl/collect_wgs_metrics/wgs_metrics",
                    "id": "#qc_wgs.cwl/wgs_metrics"
                }
            ],
            "steps": [
                {
                    "run": "#collect_alignment_summary_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_wgs.cwl/bam",
                            "id": "#qc_wgs.cwl/collect_alignment_summary_metrics/bam"
                        },
                        {
                            "source": "#qc_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#qc_wgs.cwl/collect_alignment_summary_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_wgs.cwl/reference",
                            "id": "#qc_wgs.cwl/collect_alignment_summary_metrics/reference"
                        }
                    ],
                    "out": [
                        "#qc_wgs.cwl/collect_alignment_summary_metrics/alignment_summary_metrics"
                    ],
                    "id": "#qc_wgs.cwl/collect_alignment_summary_metrics"
                },
                {
                    "run": "#collect_gc_bias_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_wgs.cwl/bam",
                            "id": "#qc_wgs.cwl/collect_gc_bias_metrics/bam"
                        },
                        {
                            "source": "#qc_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#qc_wgs.cwl/collect_gc_bias_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_wgs.cwl/reference",
                            "id": "#qc_wgs.cwl/collect_gc_bias_metrics/reference"
                        },
                        {
                            "source": "#qc_wgs.cwl/sample_name",
                            "id": "#qc_wgs.cwl/collect_gc_bias_metrics/sample_name"
                        }
                    ],
                    "out": [
                        "#qc_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics",
                        "#qc_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_chart",
                        "#qc_wgs.cwl/collect_gc_bias_metrics/gc_bias_metrics_summary"
                    ],
                    "id": "#qc_wgs.cwl/collect_gc_bias_metrics"
                },
                {
                    "run": "#hs_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_wgs.cwl/bam",
                            "id": "#qc_wgs.cwl/collect_hs_metrics/bam"
                        },
                        {
                            "source": "#qc_wgs.cwl/minimum_base_quality",
                            "id": "#qc_wgs.cwl/collect_hs_metrics/minimum_base_quality"
                        },
                        {
                            "source": "#qc_wgs.cwl/minimum_mapping_quality",
                            "id": "#qc_wgs.cwl/collect_hs_metrics/minimum_mapping_quality"
                        },
                        {
                            "source": "#qc_wgs.cwl/per_base_intervals",
                            "id": "#qc_wgs.cwl/collect_hs_metrics/per_base_intervals"
                        },
                        {
                            "source": "#qc_wgs.cwl/per_target_intervals",
                            "id": "#qc_wgs.cwl/collect_hs_metrics/per_target_intervals"
                        },
                        {
                            "source": "#qc_wgs.cwl/reference",
                            "id": "#qc_wgs.cwl/collect_hs_metrics/reference"
                        },
                        {
                            "source": "#qc_wgs.cwl/summary_intervals",
                            "id": "#qc_wgs.cwl/collect_hs_metrics/summary_intervals"
                        }
                    ],
                    "out": [
                        "#qc_wgs.cwl/collect_hs_metrics/per_base_coverage_metrics",
                        "#qc_wgs.cwl/collect_hs_metrics/per_base_hs_metrics",
                        "#qc_wgs.cwl/collect_hs_metrics/per_target_coverage_metrics",
                        "#qc_wgs.cwl/collect_hs_metrics/per_target_hs_metrics",
                        "#qc_wgs.cwl/collect_hs_metrics/summary_hs_metrics"
                    ],
                    "id": "#qc_wgs.cwl/collect_hs_metrics"
                },
                {
                    "run": "#collect_insert_size_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_wgs.cwl/bam",
                            "id": "#qc_wgs.cwl/collect_insert_size_metrics/bam"
                        },
                        {
                            "source": "#qc_wgs.cwl/picard_metric_accumulation_level",
                            "id": "#qc_wgs.cwl/collect_insert_size_metrics/metric_accumulation_level"
                        },
                        {
                            "source": "#qc_wgs.cwl/reference",
                            "id": "#qc_wgs.cwl/collect_insert_size_metrics/reference"
                        }
                    ],
                    "out": [
                        "#qc_wgs.cwl/collect_insert_size_metrics/insert_size_metrics",
                        "#qc_wgs.cwl/collect_insert_size_metrics/insert_size_histogram"
                    ],
                    "id": "#qc_wgs.cwl/collect_insert_size_metrics"
                },
                {
                    "run": "#collect_wgs_metrics.cwl",
                    "in": [
                        {
                            "source": "#qc_wgs.cwl/bam",
                            "id": "#qc_wgs.cwl/collect_wgs_metrics/bam"
                        },
                        {
                            "source": "#qc_wgs.cwl/intervals",
                            "id": "#qc_wgs.cwl/collect_wgs_metrics/intervals"
                        },
                        {
                            "source": "#qc_wgs.cwl/reference",
                            "id": "#qc_wgs.cwl/collect_wgs_metrics/reference"
                        },
                        {
                            "source": "#qc_wgs.cwl/sample_name",
                            "id": "#qc_wgs.cwl/collect_wgs_metrics/sample_name"
                        }
                    ],
                    "out": [
                        "#qc_wgs.cwl/collect_wgs_metrics/wgs_metrics"
                    ],
                    "id": "#qc_wgs.cwl/collect_wgs_metrics"
                },
                {
                    "run": "#samtools_flagstat.cwl",
                    "in": [
                        {
                            "source": "#qc_wgs.cwl/bam",
                            "id": "#qc_wgs.cwl/samtools_flagstat/bam"
                        }
                    ],
                    "out": [
                        "#qc_wgs.cwl/samtools_flagstat/flagstats"
                    ],
                    "id": "#qc_wgs.cwl/samtools_flagstat"
                },
                {
                    "run": "#verify_bam_id.cwl",
                    "in": [
                        {
                            "source": "#qc_wgs.cwl/bam",
                            "id": "#qc_wgs.cwl/verify_bam_id/bam"
                        },
                        {
                            "source": "#qc_wgs.cwl/omni_vcf",
                            "id": "#qc_wgs.cwl/verify_bam_id/vcf"
                        }
                    ],
                    "out": [
                        "#qc_wgs.cwl/verify_bam_id/verify_bam_id_metrics",
                        "#qc_wgs.cwl/verify_bam_id/verify_bam_id_depth"
                    ],
                    "id": "#qc_wgs.cwl/verify_bam_id"
                }
            ],
            "id": "#qc_wgs.cwl"
        },
        {
            "class": "Workflow",
            "label": "adapter for sequence_align_and_tag",
            "doc": "Some workflow engines won't stage files in our nested structure, so parse it out here",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        },
                        {
                            "$import": "#trimming_options.yml/trimming_options"
                        }
                    ]
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "doc": "bwa-indexed reference file",
                    "id": "#sequence_align_and_tag_adapter.cwl/reference"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "id": "#sequence_align_and_tag_adapter.cwl/trimming"
                },
                {
                    "type": "#sequence_data.yml/sequence_data",
                    "doc": "the unaligned sequence data with readgroup information",
                    "id": "#sequence_align_and_tag_adapter.cwl/unaligned"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#sequence_align_and_tag_adapter.cwl/align_and_tag/aligned_bam",
                    "id": "#sequence_align_and_tag_adapter.cwl/aligned_bam"
                }
            ],
            "steps": [
                {
                    "run": "#sequence_align_and_tag.cwl",
                    "in": [
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('bam')? self.sequence.bam : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/bam"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq1')? self.sequence.fastq1 : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/fastq1"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.sequence.hasOwnProperty('fastq2')? self.sequence.fastq2 : null)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/fastq2"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/unaligned",
                            "valueFrom": "$(self.readgroup)",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/readgroup"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/reference",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/reference"
                        },
                        {
                            "source": "#sequence_align_and_tag_adapter.cwl/trimming",
                            "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag/trimming"
                        }
                    ],
                    "out": [
                        "#sequence_align_and_tag_adapter.cwl/align_and_tag/aligned_bam"
                    ],
                    "id": "#sequence_align_and_tag_adapter.cwl/align_and_tag"
                }
            ],
            "id": "#sequence_align_and_tag_adapter.cwl"
        },
        {
            "class": "Workflow",
            "label": "Raw sequence data to BQSR",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        },
                        {
                            "$import": "#trimming_options.yml/trimming_options"
                        }
                    ]
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "id": "#sequence_to_bqsr.cwl/bqsr_intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "One or more databases of known polymorphic sites used to exclude regions around known polymorphisms from analysis.",
                    "id": "#sequence_to_bqsr.cwl/bqsr_known_sites"
                },
                {
                    "type": "string",
                    "default": "final",
                    "id": "#sequence_to_bqsr.cwl/final_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#sequence_to_bqsr.cwl/reference"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "id": "#sequence_to_bqsr.cwl/trimming"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "#sequence_data.yml/sequence_data"
                    },
                    "id": "#sequence_to_bqsr.cwl/unaligned"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#sequence_to_bqsr.cwl/index_bam/indexed_bam",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "id": "#sequence_to_bqsr.cwl/final_bam"
                },
                {
                    "type": "File",
                    "outputSource": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/metrics_file",
                    "id": "#sequence_to_bqsr.cwl/mark_duplicates_metrics_file"
                }
            ],
            "steps": [
                {
                    "scatter": [
                        "#sequence_to_bqsr.cwl/align/unaligned"
                    ],
                    "scatterMethod": "dotproduct",
                    "run": "#sequence_align_and_tag_adapter.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/reference",
                            "id": "#sequence_to_bqsr.cwl/align/reference"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/trimming",
                            "id": "#sequence_to_bqsr.cwl/align/trimming"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/unaligned",
                            "id": "#sequence_to_bqsr.cwl/align/unaligned"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/align/aligned_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/align"
                },
                {
                    "run": "#apply_bqsr.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/bam"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/bqsr/bqsr_table",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/bqsr_table"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/final_name",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/output_name"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/reference",
                            "id": "#sequence_to_bqsr.cwl/apply_bqsr/reference"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/apply_bqsr/bqsr_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/apply_bqsr"
                },
                {
                    "run": "#bqsr.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                            "id": "#sequence_to_bqsr.cwl/bqsr/bam"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/bqsr_intervals",
                            "id": "#sequence_to_bqsr.cwl/bqsr/intervals"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/bqsr_known_sites",
                            "id": "#sequence_to_bqsr.cwl/bqsr/known_sites"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/reference",
                            "id": "#sequence_to_bqsr.cwl/bqsr/reference"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/bqsr/bqsr_table"
                    ],
                    "id": "#sequence_to_bqsr.cwl/bqsr"
                },
                {
                    "run": "#index_bam.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/apply_bqsr/bqsr_bam",
                            "id": "#sequence_to_bqsr.cwl/index_bam/bam"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/index_bam/indexed_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/index_bam"
                },
                {
                    "run": "#mark_duplicates_and_sort.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/name_sort/name_sorted_bam",
                            "id": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/bam"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/sorted_bam",
                        "#sequence_to_bqsr.cwl/mark_duplicates_and_sort/metrics_file"
                    ],
                    "id": "#sequence_to_bqsr.cwl/mark_duplicates_and_sort"
                },
                {
                    "run": "#merge_bams_samtools.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/align/aligned_bam",
                            "id": "#sequence_to_bqsr.cwl/merge/bams"
                        },
                        {
                            "source": "#sequence_to_bqsr.cwl/final_name",
                            "id": "#sequence_to_bqsr.cwl/merge/name"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/merge/merged_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/merge"
                },
                {
                    "run": "#name_sort.cwl",
                    "in": [
                        {
                            "source": "#sequence_to_bqsr.cwl/merge/merged_bam",
                            "id": "#sequence_to_bqsr.cwl/name_sort/bam"
                        }
                    ],
                    "out": [
                        "#sequence_to_bqsr.cwl/name_sort/name_sorted_bam"
                    ],
                    "id": "#sequence_to_bqsr.cwl/name_sort"
                }
            ],
            "id": "#sequence_to_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "apply BQSR",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "ApplyBQSR"
            ],
            "arguments": [
                "-O",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.output_name).bam"
                },
                "--static-quantized-quals",
                "10",
                "--static-quantized-quals",
                "20",
                "--static-quantized-quals",
                "30"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#apply_bqsr.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-bqsr",
                        "position": 3
                    },
                    "id": "#apply_bqsr.cwl/bqsr_table"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#apply_bqsr.cwl/output_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#apply_bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name).bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#apply_bqsr.cwl/bqsr_bam"
                }
            ],
            "id": "#apply_bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "BAM to CRAM conversion",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "view",
                "-C"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "stdout": "$(inputs.bam.nameroot).cram",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#bam_to_cram.cwl/bam"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-T",
                        "position": 1
                    },
                    "id": "#bam_to_cram.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#bam_to_cram.cwl/cram",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).cram"
                    }
                }
            ],
            "id": "#bam_to_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "create BQSR table",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "BaseRecalibrator"
            ],
            "arguments": [
                "-O",
                {
                    "valueFrom": "$(runtime.outdir)/bqsr.table"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 3
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#bqsr.cwl/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "default": [
                        "chr1",
                        "chr2",
                        "chr3",
                        "chr4",
                        "chr5",
                        "chr6",
                        "chr7",
                        "chr8",
                        "chr9",
                        "chr10",
                        "chr11",
                        "chr12",
                        "chr13",
                        "chr14",
                        "chr15",
                        "chr16",
                        "chr17",
                        "chr18",
                        "chr19",
                        "chr20",
                        "chr21",
                        "chr22"
                    ],
                    "id": "#bqsr.cwl/intervals"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--known-sites",
                            "position": 4
                        }
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#bqsr.cwl/known_sites"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 2
                    },
                    "id": "#bqsr.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "bqsr.table"
                    },
                    "id": "#bqsr.cwl/bqsr_table"
                }
            ],
            "id": "#bqsr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect alignment summary metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectAlignmentSummaryMetrics"
            ],
            "arguments": [
                "OUTPUT=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).AlignmentSummaryMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "INPUT="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_alignment_summary_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).AlignmentSummaryMetrics.txt"
                    },
                    "id": "#collect_alignment_summary_metrics.cwl/alignment_summary_metrics"
                }
            ],
            "id": "#collect_alignment_summary_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect gc bias metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectGcBiasMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.sample_name).GcBiasMetrics.txt"
                },
                "CHART=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.sample_name).GcBiasMetricsChart.pdf"
                },
                "S=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.sample_name).GcBiasMetricsSummary.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_gc_bias_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_gc_bias_metrics.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#collect_gc_bias_metrics.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).GcBiasMetrics.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).GcBiasMetricsChart.pdf"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_chart"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).GcBiasMetricsSummary.txt"
                    },
                    "id": "#collect_gc_bias_metrics.cwl/gc_bias_metrics_summary"
                }
            ],
            "id": "#collect_gc_bias_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect HS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx48g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectHsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 52000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "BAIT_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/bait_intervals"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_hs_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_hs_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1,
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_hs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "out",
                    "id": "#collect_hs_metrics.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_BASE_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.bam.nameroot + \".\" + inputs.output_prefix + \"-PerBaseCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "PER_TARGET_COVERAGE=",
                        "valueFrom": "${\n    if(self) {\n        return inputs.bam.nameroot + \".\" + inputs.output_prefix + \"-PerTargetCoverage.txt\"\n    } else {\n        return false;\n    }\n}\n"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_hs_metrics.cwl/reference"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "TARGET_INTERVALS="
                    },
                    "id": "#collect_hs_metrics.cwl/target_intervals"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-HsMetrics.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/hs_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-PerBaseCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_base_coverage_metrics"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).$(inputs.output_prefix)-PerTargetCoverage.txt"
                    },
                    "id": "#collect_hs_metrics.cwl/per_target_coverage_metrics"
                }
            ],
            "id": "#collect_hs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect insert size metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectInsertSizeMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).InsertSizeMetrics.txt"
                },
                "H=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).InsertSizeHistogram.pdf"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_insert_size_metrics.cwl/bam"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "METRIC_ACCUMULATION_LEVEL="
                    },
                    "id": "#collect_insert_size_metrics.cwl/metric_accumulation_level"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "REFERENCE_SEQUENCE="
                    },
                    "id": "#collect_insert_size_metrics.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).InsertSizeHistogram.pdf"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_histogram"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).InsertSizeMetrics.txt"
                    },
                    "id": "#collect_insert_size_metrics.cwl/insert_size_metrics"
                }
            ],
            "id": "#collect_insert_size_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "collect WGS metrics",
            "baseCommand": [
                "/usr/bin/java",
                "-Xmx16g",
                "-jar",
                "/usr/picard/picard.jar",
                "CollectWgsMetrics"
            ],
            "arguments": [
                "O=",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.sample_name).WgsMetrics.txt"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/picard:2.23.6"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "I="
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#collect_wgs_metrics.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "INTERVALS="
                    },
                    "id": "#collect_wgs_metrics.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum base quality for a base to contribute coverage. (N bases are considered to have negative infinite quality and will be excluded regardless of this value.)",
                    "inputBinding": {
                        "prefix": "MINIMUM_BASE_QUALITY="
                    },
                    "id": "#collect_wgs_metrics.cwl/minimum_base_quality"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Minimum mapping quality for a read to contribute coverage.",
                    "inputBinding": {
                        "prefix": "MINIMUM_MAPPING_QUALITY="
                    },
                    "id": "#collect_wgs_metrics.cwl/minimum_mapping_quality"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "R="
                    },
                    "id": "#collect_wgs_metrics.cwl/reference"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "final",
                    "id": "#collect_wgs_metrics.cwl/sample_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.sample_name).WgsMetrics.txt"
                    },
                    "id": "#collect_wgs_metrics.cwl/wgs_metrics"
                }
            ],
            "id": "#collect_wgs_metrics.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "GATK HaplotypeCaller",
            "baseCommand": [
                "/gatk/gatk",
                "--java-options",
                "-Xmx16g",
                "HaplotypeCaller"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 18000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "broadinstitute/gatk:4.1.8.1"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-I",
                        "position": 2
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-contamination",
                        "position": 7
                    },
                    "id": "#gatk_haplotype_caller.cwl/contamination_fraction"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--dbsnp",
                        "position": 6
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/dbsnp_vcf"
                },
                {
                    "type": {
                        "type": "enum",
                        "symbols": [
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/NONE",
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/BP_RESOLUTION",
                            "#gatk_haplotype_caller.cwl/emit_reference_confidence/GVCF"
                        ]
                    },
                    "inputBinding": {
                        "prefix": "-ERC",
                        "position": 3
                    },
                    "id": "#gatk_haplotype_caller.cwl/emit_reference_confidence"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-GQB"
                        }
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#gatk_haplotype_caller.cwl/gvcf_gq_bands"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string",
                        "inputBinding": {
                            "prefix": "-L"
                        }
                    },
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#gatk_haplotype_caller.cwl/intervals"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "maximum number of alternate alleles to genotype",
                    "inputBinding": {
                        "prefix": "--max_alternate_alleles",
                        "position": 8
                    },
                    "id": "#gatk_haplotype_caller.cwl/max_alternate_alleles"
                },
                {
                    "type": "string",
                    "default": "output.g.vcf.gz",
                    "inputBinding": {
                        "prefix": "-O",
                        "position": 11
                    },
                    "id": "#gatk_haplotype_caller.cwl/output_file_name"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "number of chromosomes per sample",
                    "inputBinding": {
                        "prefix": "-ploidy",
                        "position": 9
                    },
                    "id": "#gatk_haplotype_caller.cwl/ploidy"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "filters to apply to reads before analysis",
                    "inputBinding": {
                        "prefix": "--read_filter",
                        "position": 10
                    },
                    "id": "#gatk_haplotype_caller.cwl/read_filter"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "prefix": "-R",
                        "position": 1
                    },
                    "id": "#gatk_haplotype_caller.cwl/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_file_name)"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#gatk_haplotype_caller.cwl/gvcf"
                }
            ],
            "id": "#gatk_haplotype_caller.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index",
            "arguments": [
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.bam.basename)",
                "$(runtime.outdir)/$(inputs.bam.basename).bai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.bam.basename).bai",
                "$(runtime.outdir)/$(inputs.bam.nameroot).bai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.bam; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_bam.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai",
                        "^.bai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename)"
                    },
                    "id": "#index_bam.cwl/indexed_bam"
                }
            ],
            "id": "#index_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools index cram",
            "arguments": [
                "/opt/samtools/bin/samtools",
                "index",
                "$(runtime.outdir)/$(inputs.cram.basename)",
                "$(runtime.outdir)/$(inputs.cram.basename).crai",
                {
                    "valueFrom": " && ",
                    "shellQuote": false
                },
                "cp",
                "$(inputs.cram.basename).crai",
                "$(runtime.outdir)/$(inputs.cram.nameroot).crai"
            ],
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "${ var f = inputs.cram; delete f.secondaryFiles; return f }"
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#index_cram.cwl/cram"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".crai",
                        "^.crai"
                    ],
                    "outputBinding": {
                        "glob": "$(inputs.cram.basename)"
                    },
                    "id": "#index_cram.cwl/indexed_cram"
                }
            ],
            "id": "#index_cram.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Mark duplicates and Sort",
            "baseCommand": [
                "/bin/bash",
                "markduplicates_helper.sh"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 40000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mark_duplicates-cwl:1.0.1"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "markduplicates_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\n\ndeclare MD_BARCODE_TAG\nif [ ! -z \"$6\" ]; then\n  MD_BARCODE_TAG=\"BARCODE_TAG=$6\"\n/usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT \"$MD_BARCODE_TAG\" | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nelse\n  /usr/bin/java -Xmx16g -jar /opt/picard/picard.jar MarkDuplicates I=$1 O=/dev/stdout ASSUME_SORT_ORDER=$5 METRICS_FILE=$4 QUIET=true COMPRESSION_LEVEL=0 VALIDATION_STRINGENCY=LENIENT | /usr/bin/sambamba sort -t $2 -m 18G -o $3 /dev/stdin\nfi\n"
                        }
                    ]
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(runtime.cores)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#mark_duplicates_and_sort.cwl/bam"
                },
                {
                    "type": "string",
                    "default": "queryname",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#mark_duplicates_and_sort.cwl/input_sort_order"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "MarkedSorted.bam",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#mark_duplicates_and_sort.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).mark_dups_metrics.txt"
                    },
                    "id": "#mark_duplicates_and_sort.cwl/metrics_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#mark_duplicates_and_sort.cwl/sorted_bam"
                }
            ],
            "id": "#mark_duplicates_and_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Samtools: merge",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "merge"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "arguments": [
                "$(inputs.name).merged.bam",
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#merge_bams_samtools.cwl/bams"
                },
                {
                    "type": "string",
                    "id": "#merge_bams_samtools.cwl/name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name).merged.bam"
                    },
                    "id": "#merge_bams_samtools.cwl/merged_bam"
                }
            ],
            "id": "#merge_bams_samtools.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "sort BAM by name",
            "baseCommand": [
                "/usr/bin/sambamba",
                "sort"
            ],
            "arguments": [
                "-t",
                {
                    "valueFrom": "$(runtime.cores)"
                },
                "-m",
                "22G",
                "-n",
                "-o",
                {
                    "valueFrom": "$(inputs.bam.nameroot).NameSorted.bam"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 26000,
                    "coresMin": 8
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/sambamba-cwl:0.6.4"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#name_sort.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).NameSorted.bam"
                    },
                    "id": "#name_sort.cwl/name_sorted_bam"
                }
            ],
            "id": "#name_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "samtools flagstat",
            "baseCommand": [
                "/opt/samtools/bin/samtools",
                "flagstat"
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/samtools-cwl:1.0.0"
                }
            ],
            "stdout": "$(inputs.bam.basename).flagstat",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "id": "#samtools_flagstat.cwl/bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_flagstat.cwl/flagstats",
                    "outputBinding": {
                        "glob": "$(inputs.bam.basename).flagstat"
                    }
                }
            ],
            "id": "#samtools_flagstat.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "align with bwa_mem and tag",
            "doc": "Due to workflow runner limitations, use sequence_align_and_tag_adapter.cwl subworkflow to call this",
            "baseCommand": [
                "/bin/bash",
                "sequence_alignment_helper.sh"
            ],
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#sequence_data.yml/sequence_data"
                        },
                        {
                            "$import": "#trimming_options.yml/trimming_options"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 8,
                    "ramMin": 20000
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/alignment_helper-cwl:1.1.0"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "sequence_alignment_helper.sh",
                            "entry": "set -o pipefail\nset -o errexit\nset -o nounset\n\nRUN_TRIMMING=\"false\"\n\nwhile getopts \"b:?1:?2:?g:r:n:t:?o:?\" opt; do\n    case \"$opt\" in\n        b)\n            MODE=bam\n            BAM=\"$OPTARG\"\n            ;;\n        1)\n            MODE=fastq\n            FASTQ1=\"$OPTARG\"\n            ;;\n        2)  \n            MODE=fastq\n            FASTQ2=\"$OPTARG\"\n            ;;\n        g)\n            READGROUP=\"$OPTARG\"\n            ;;\n        r)\n            REFERENCE=\"$OPTARG\"\n            ;;\n        n)\n            NTHREADS=\"$OPTARG\"\n            ;;\n        t)\n            RUN_TRIMMING=\"true\"\n            TRIMMING_ADAPTERS=\"$OPTARG\"\n            ;;\n        o)\n            RUN_TRIMMING=\"true\"\n            TRIMMING_ADAPTER_MIN_OVERLAP=\"$OPTARG\"\n            ;;\n    esac\ndone\n\nif [[ \"$MODE\" == 'fastq' ]]; then\n    if [[ \"$RUN_TRIMMING\" == 'false' ]]; then\n        /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -R \"$READGROUP\" \"$REFERENCE\" \"$FASTQ1\" \"$FASTQ2\" | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    else\n        /opt/flexbar/flexbar --adapters \"$TRIMMING_ADAPTERS\" --reads \"$FASTQ1\" --reads2 \"$FASTQ2\" --adapter-trim-end LTAIL --adapter-min-overlap \"$TRIMMING_ADAPTER_MIN_OVERLAP\" --adapter-error-rate 0.1 --max-uncalled 300 --stdout-reads \\\n          | /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -p -R \"$READGROUP\" \"$REFERENCE\" /dev/stdin | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    fi\nfi\nif [[ \"$MODE\" == 'bam' ]]; then\n    if [[ \"$RUN_TRIMMING\" == 'false' ]]; then\n        /usr/bin/java -Xmx4g -jar /opt/picard/picard.jar SamToFastq I=\"$BAM\" INTERLEAVE=true INCLUDE_NON_PF_READS=true FASTQ=/dev/stdout | /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -p -R \"$READGROUP\" \"$REFERENCE\" /dev/stdin | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    else\n       /usr/bin/java -Xmx4g -jar /opt/picard/picard.jar SamToFastq I=\"$BAM\" INTERLEAVE=true INCLUDE_NON_PF_READS=true FASTQ=/dev/stdout \\\n         | /opt/flexbar/flexbar --adapters \"$TRIMMING_ADAPTERS\" --reads - --interleaved --adapter-trim-end LTAIL --adapter-min-overlap \"$TRIMMING_ADAPTER_MIN_OVERLAP\" --adapter-error-rate 0.1 --max-uncalled 300 --stdout-reads \\\n         | /usr/local/bin/bwa mem -K 100000000 -t \"$NTHREADS\" -Y -p -R \"$READGROUP\" \"$REFERENCE\" /dev/stdin | /usr/local/bin/samblaster -a --addMateTags | /opt/samtools/bin/samtools view -b -S /dev/stdin\n    fi\nfi\n"
                        }
                    ]
                }
            ],
            "stdout": "refAlign.bam",
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "position": 5,
                    "prefix": "-n"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-b"
                    },
                    "id": "#sequence_align_and_tag.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-1"
                    },
                    "id": "#sequence_align_and_tag.cwl/fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "-2"
                    },
                    "id": "#sequence_align_and_tag.cwl/fastq2"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "id": "#sequence_align_and_tag.cwl/readgroup"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "inputBinding": {
                        "position": 4,
                        "prefix": "-r"
                    },
                    "doc": "bwa-indexed reference file",
                    "id": "#sequence_align_and_tag.cwl/reference"
                },
                {
                    "type": [
                        "#trimming_options.yml/trimming_options",
                        "null"
                    ],
                    "inputBinding": {
                        "valueFrom": "$( ['-t', self.adapters.path, '-o', self.min_overlap] )"
                    },
                    "id": "#sequence_align_and_tag.cwl/trimming"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#sequence_align_and_tag.cwl/aligned_bam",
                    "outputBinding": {
                        "glob": "refAlign.bam"
                    }
                }
            ],
            "id": "#sequence_align_and_tag.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "verify BAM ID",
            "baseCommand": "/usr/local/bin/verifyBamID",
            "arguments": [
                "--out",
                {
                    "valueFrom": "$(runtime.outdir)/$(inputs.bam.nameroot).VerifyBamId"
                }
            ],
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/verify_bam_id-cwl:1.1.3"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--bam"
                    },
                    "id": "#verify_bam_id.cwl/bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--vcf"
                    },
                    "id": "#verify_bam_id.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.depthSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_depth"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot).VerifyBamId.selfSM"
                    },
                    "id": "#verify_bam_id.cwl/verify_bam_id_metrics"
                }
            ],
            "id": "#verify_bam_id.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
